diff --git a/router/java/src/net/i2p/router/transport/tcp/RestrictiveTCPConnection.java b/router/java/src/net/i2p/router/transport/tcp/RestrictiveTCPConnection.java
index 7678b3334a76801aa0cd4282c15d3997b068ce3a..ad482f5232633ec569bd41d46cc7e0e43d2913d0 100644
--- a/router/java/src/net/i2p/router/transport/tcp/RestrictiveTCPConnection.java
+++ b/router/java/src/net/i2p/router/transport/tcp/RestrictiveTCPConnection.java
@@ -44,10 +44,10 @@ class RestrictiveTCPConnection extends TCPConnection {
     }
     
     /** passed in the handshake process for the connection, and only equivilant protocols will be accepted */
-    private final static long PROTO_ID = 12;
+    private final static long PROTO_ID = 13;
     
     /** read / write buffer size */
-    private final static int BUF_SIZE = 32*1024;
+    private final static int BUF_SIZE = 2*1024;
     
     private boolean validateVersion() throws DataFormatException, IOException {
         if (_log.shouldLog(Log.DEBUG)) _log.debug("Before validating version");
diff --git a/router/java/src/net/i2p/router/transport/tcp/SocketCreator.java b/router/java/src/net/i2p/router/transport/tcp/SocketCreator.java
index 787ce9b6333ae74db13935184e4f83ae080b4b69..a9a8e0713f5bde2511a8985916b64d37eaaa6fdf 100644
--- a/router/java/src/net/i2p/router/transport/tcp/SocketCreator.java
+++ b/router/java/src/net/i2p/router/transport/tcp/SocketCreator.java
@@ -30,8 +30,8 @@ class SocketCreator implements Runnable {
     
     public boolean couldEstablish() { return _established; }
     
-    /** the first byte sent and received must be 0x2A */
-    public final static int I2P_FLAG = 0x2A;
+    /** the first byte sent and received must be 0x42 */
+    public final static int I2P_FLAG = 0x42;
     /** sent if we arent trying to talk */
     private final static int NOT_I2P_FLAG = 0x2B;